@@ -168,9 +168,17 @@ class AggcatClient(object):
                     Objectify(response.content).get_object()
                 )
             except etree.XMLSyntaxError:
-                return None
+                # this errors happens when the response is blank
+                # in case of this error or others in the objectifier
+                # pass and give the response unobjectified
+                pass
+
+        return AggCatResponse(
+            response.status_code,
+            response.headers,
+            response.content
+        )
 
-        return AggCatResponse(response.status_code, response.content)
 
     def _remove_namespaces(self, tree):
         """Remove the namspaces from the Intuit XML for easier parsing"""
